DxtDecoder

Struct DxtDecoder 

pub struct DxtDecoder<R>
where R: Read,
{ /* private fields */ }
DXT decoder

Implementations

Source

impl<R> DxtDecoder<R>
where R: Read,

pub fn new( r: R, width: u32, height: u32, variant: DXTVariant, ) -> Result<DxtDecoder<R>, ImageError>

Create a new DXT decoder that decodes from the stream r. As DXT is often stored as raw buffers with the width/height somewhere else the width and height of the image need to be passed in width and height, as well as the DXT variant in variant. width and height are required to be powers of 2 and at least 4. otherwise an error will be returned