PNMHeader

Struct PNMHeader 

pub struct PNMHeader { /* private fields */ }
Stores the complete header data of a file.

Internally, provides mechanisms for lossless reencoding. After reading a file with the decoder it is possible to recover the header and construct an encoder. Using the encoder on the just loaded image should result in a byte copy of the original file (for single image pnms without additional trailing data).

Implementations

Source

impl PNMHeader

pub fn subtype(&self) -> PNMSubtype

Retrieve the format subtype from which the header was created.

pub fn width(&self) -> u32

The width of the image this header is for.

pub fn height(&self) -> u32

The height of the image this header is for.

pub fn maximal_sample(&self) -> u32

The biggest value a sample can have. In other words, the colour resolution.

pub fn as_bitmap(&self) -> Option<&BitmapHeader>

Retrieve the underlying bitmap header if any

pub fn as_graymap(&self) -> Option<&GraymapHeader>

Retrieve the underlying graymap header if any

pub fn as_pixmap(&self) -> Option<&PixmapHeader>

Retrieve the underlying pixmap header if any

pub fn as_arbitrary(&self) -> Option<&ArbitraryHeader>

Retrieve the underlying arbitrary header if any

pub fn write(&self, writer: &mut dyn Write) -> Result<(), Error>

Write the header back into a binary stream